@@ -15,6 +15,9 @@ sub _init {
     $initialized = 1;
 
     return if Module::Build->current->notes( 'build_wx' );
+    # install_only is set when a wxWidgets build is already configured
+    # with Alien::wxWidgets
+    return if Module::Build->current->notes( 'install_only' );
 
     # check for WXDIR and WXWIN environment variables
     unless( exists $ENV{WXDIR} or exists $ENV{WXWIN} ) {
@@ -37,7 +40,8 @@ EOT
 
 sub _patch_command {
     my( $self, $base_dir, $patch_file ) = @_;
-    my $patch_exe = File::Spec->catfile( $base_dir, qw(inc bin patch.exe) );
+    my $patch_exe = File::Spec->catfile( File::Spec->updir,
+                                         qw(inc bin patch.exe) );
 
     my $cmd = qq{perl -pe "" -- $patch_file} .
               qq{ | $patch_exe -N -p0 -u -b -z .bak};
@@ -208,7 +212,7 @@ sub awx_get_package {
     return 'WinCE' if $INC{'Cross.pm'};
 
     SWITCH: {
-        local $_ = $Config{ccname};
+        local $_ = $Config{ccname} || $Config{cc};
 
         /^cl/i  and $package = 'Win32_MSVC'  and last SWITCH;
         /^gcc/i and $package = 'Win32_MinGW' and last SWITCH;
@@ -217,20 +221,15 @@ sub awx_get_package {
         die "Your compiler is not currently supported on Win32"
     };
 
-    if( Module::Build->current->notes( 'build_wx' ) ) {
-        return $package . '_Bakefile';
-    } else {
-        my $mak_env_in =
-          File::Spec->catfile( $ENV{WXDIR}, 'src', 'make.env.in' );
-        return -f $mak_env_in ? $package . '_Tmake' : $package . '_Bakefile';
-    }
+    return $package . '_Bakefile';
 }
 
 # MSLU is default when using Unicode *and* it has not
 # been explicitly disabled
 sub awx_mslu {
-    return $_[0]->args( 'mslu' ) if defined $_[0]->args( 'mslu' );
-    return $_[0]->awx_unicode;
+    return $_[0]->args( 'wxWidgets-mslu' )
+      if defined $_[0]->args( 'wxWidgets-mslu' );
+    return $_[0]->args( 'wxWidgets-unicode' );
 }
 
 sub massage_environment {
